@@ -1,5 +1,6 @@
 import logging
 
+from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
 
 
@@ -20,6 +21,7 @@ class CatalogSource(NamespacedResource):
         publisher=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
     ):
         super().__init__(
             name=name,
@@ -27,6 +29,7 @@ class CatalogSource(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
         )
         self.source_type = source_type
         self.image = image
