@@ -2,8 +2,8 @@ import logging
 
 import kubernetes
 
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT
-from ocp_resources.resource import TIMEOUT, NamespacedResource
+from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
+from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 
 
@@ -17,7 +17,7 @@ class DaemonSet(NamespacedResource):
 
     api_group = NamespacedResource.ApiGroup.APPS
 
-    def wait_until_deployed(self, timeout=TIMEOUT):
+    def wait_until_deployed(self, timeout=TIMEOUT_4MINUTES):
         """
         Wait until all Pods are deployed and ready.
 
@@ -47,7 +47,7 @@ class DaemonSet(NamespacedResource):
                 ):
                     return
 
-    def delete(self, wait=False, timeout=TIMEOUT, body=None):
+    def delete(self, wait=False, timeout=TIMEOUT_4MINUTES, body=None):
         """
         Delete Daemonset
 
